# ApplicationMonitoringConfig

The prometheus monitoring config
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**port** | **int** | The port to access for metrics. If unset uses the application&#39;s port. | [optional] 
**path** | **str** | The path to scrape prometheus metrics from | [optional] [default to '/metrics']

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


